==> sherpa_client-0.12.6.tar.gz: sherpa_client-0.12.6/sherpa_client/api/roles/get_role.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import Client
from ...models.role_desc import RoleDesc
from ...types import Response


def _get_kwargs(
    rolename: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/roles/{rolename}".format(client.base_url, rolename=rolename)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Union[Any, RoleDesc]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RoleDesc.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[Union[Any, RoleDesc]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    rolename: str,
    *,
    client: Client,
) -> Response[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, RoleDesc]]
    """

    kwargs = _get_kwargs(
        rolename=rolename,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    rolename: str,
    *,
    client: Client,
) -> Optional[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, RoleDesc]]
    """

    return sync_detailed(
        rolename=rolename,
        client=client,
    ).parsed


async def asyncio_detailed(
    rolename: str,
    *,
    client: Client,
) -> Response[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, RoleDesc]]
    """

    kwargs = _get_kwargs(
        rolename=rolename,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    rolename: str,
    *,
    client: Client,
) -> Optional[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, RoleDesc]]
    """

    return (
        await asyncio_detailed(
            rolename=rolename,
            client=client,
        )
    ).parsed

==> sherpa_client-1.0.3.tar.gz: sherpa_client-1.0.3/sherpa_client/api/roles/get_role.py <==
from http import HTTPStatus
from typing import Any, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.role_desc import RoleDesc
from ...types import Response


def _get_kwargs(
    rolename: str,
) -> dict[str, Any]:

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/roles/{rolename}".format(
            rolename=rolename,
        ),
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, RoleDesc]]:
    if response.status_code == 200:
        response_200 = RoleDesc.from_dict(response.json())

        return response_200
    if response.status_code == 404:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, RoleDesc]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    rolename: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, RoleDesc]]
    """

    kwargs = _get_kwargs(
        rolename=rolename,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    rolename: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, RoleDesc]
    """

    return sync_detailed(
        rolename=rolename,
        client=client,
    ).parsed


async def asyncio_detailed(
    rolename: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Response[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, RoleDesc]]
    """

    kwargs = _get_kwargs(
        rolename=rolename,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    rolename: str,
    *,
    client: Union[AuthenticatedClient, Client],
) -> Optional[Union[Any, RoleDesc]]:
    """Get role

    Args:
        rolename (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, RoleDesc]
    """

    return (
        await asyncio_detailed(
            rolename=rolename,
            client=client,
        )
    ).parsed
